@@ -302,14 +302,20 @@ impl Preferences {
     }
 
 
-    pub fn read_from_disk(filename: &str) -> Result<Preferences, String> {
-        if let Ok(from_disk) = fs::read_to_string(Path::new(filename)) {
+    pub fn read_from_filename(filename: &str) -> Result<Preferences, String> {
+        Self::read_from_path(Path::new(filename))
+    }
+
+
+    pub fn read_from_path(path: &Path) -> Result<Preferences, String> {
+        if let Ok(from_disk) = fs::read_to_string(path) {
             serde_json::from_str(&from_disk).or_else(
-                |_| Err(format!("Could not read preferences from {}", filename))
+                |_| Err(format!("Could not read preferences from {}",
+                        path.display()))
             )
         }
         else {
-            Err(format!("Couldn't read {}", filename))
+            Err(format!("Couldn't read {}", path.display()))
         }
     }
 }
@@ -378,6 +384,18 @@ impl fmt::Debug for State {
 
 
 impl State {
+    pub fn pretty_color_state(&self) -> String {
+        if self.prefs.color {
+            format!("{}{}{}{}{}", Color::Red.paint("c"),
+                    Color::Yellow.paint("o"), Color::Green.paint("l"),
+                    Color::Blue.paint("o"), Color::Purple.paint("r"))
+        }
+        else {
+            "color".to_owned()
+        }
+    }
+
+
     /// Return the byte numbers necessary for the left column of a display
     pub fn addresses(&self, from:usize) -> Vec<usize> {
         // TODO Do this with a generator once
@@ -657,40 +675,50 @@ impl State {
 impl fmt::Display for State {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let mut to_write:String;
-        to_write = format!("Filename: {}\n", self.filename);
-        to_write += &format!("At byte {} of {}\n", lino(&self),
+        to_write = "State:\n".to_owned();
+        to_write += &format!("  Filename: {}\n", self.filename);
+        to_write += &format!("  At byte {} of {}\n", lino(&self),
                 hex_unless_dec_with_radix(self.all_bytes.len(), self.prefs.radix));
+        if self.unsaved_changes {
+            to_write += &format!("  Unwritten changes\n");
+        }
+        else {
+            to_write += &format!("  No unwritten changes\n");
+        }
+        if self.readonly {
+            to_write += &format!("  In read-only mode\n");
+        }
+
+        to_write += "  Preferences:\n";
+
         if self.prefs.show_byte_numbers {
-            to_write += &format!("Printing byte numbers in {}\n",
+            to_write += &format!("    Printing byte numbers in {}\n",
                 string_from_radix(self.prefs.radix));
         };
         if self.prefs.show_chars {
-            to_write += &format!("Printing char representations after bytes\n");
+            to_write +=
+                    &format!("    Printing char representations after bytes\n");
         };
-        to_write += &format!("Interpreting input numbers as {}\n",
+        to_write += &format!("    Interpreting input numbers as {}\n",
                 string_from_radix(self.prefs.radix));
-        to_write += &format!("Printing a newline every {} bytes\n",
-                hex_unless_dec_with_radix(usize::from(self.prefs.width), self.prefs.radix));
-
+        to_write += &format!("    Printing a newline every {} bytes\n",
+                hex_unless_dec_with_radix(usize::from(self.prefs.width),
+                        self.prefs.radix));
         if self.prefs.before_context > 0 {
-            to_write += &format!("Printing {} lines before current line\n",
-            hex_unless_dec_with_radix(self.prefs.before_context, self.prefs.radix));
+            to_write += &format!("    Printing {} lines before current line\n",
+            hex_unless_dec_with_radix(self.prefs.before_context,
+                    self.prefs.radix));
         };
-
         if self.prefs.after_context > 0 {
-            to_write += &format!("Printing {} lines after current line\n",
-            hex_unless_dec_with_radix(self.prefs.after_context, self.prefs.radix));
+            to_write += &format!("    Printing {} lines after current line\n",
+            hex_unless_dec_with_radix(self.prefs.after_context,
+                    self.prefs.radix));
         };
-
-        if self.unsaved_changes {
-            to_write += &format!("Unwritten changes\n")
+        if self.prefs.color {
+            to_write += &format!("    Using {}", self.pretty_color_state());
         }
         else {
-            to_write += &format!("No unwritten changes\n")
-        }
-
-        if self.readonly {
-            to_write += &format!("In read-only mode\n")
+            to_write += "    Printing without color";
         }
 
         write!(f, "{}", to_write)
